==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/mk.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Тема со висок контраст",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Тема со висок контраст за да ја олесни навигацијата. Визуелниот квалитет ќе се намали, но јасноста ќе се зголеми.",
    "Dark theme (beta)" : "Темна тема (бета)",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Темна тема за да ви го олесни гледањето преку намалување на вкупната осветленост. Сеуште е во развој, затоа ве молиме пријавете ги сите проблеми кои ќе ги најдете.",
    "Dyslexia font" : "Фонт за дислексија",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic е бесплатен фонт дизајниран за ублажување на некои од честите грешки во читањето предизвикани од дислексија.",
    "Accessibility" : "Пристапност",
    "Accessibility options for nextcloud" : "Опции за пристапност на Nextcloud. ",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Овозможува повеќе опции за пристапност за да се олесни употребата на Nextcloud",
    "Web Content Accessibility Guidelines" : "Упатства за пристапност на веб содржини",
    "our issue tracker" : "нашиот следач на проблеми",
    "our design team" : "нашиот тим за дизајн",
    "Enable" : "овозможи"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-16.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/mk.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Тема со висок контраст",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Тема со висок контраст за да ја олесни навигацијата. Визуелниот квалитет ќе се намали, но јасноста ќе се зголеми.",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Темна тема за да ви го олесни гледањето преку намалување на вкупната осветленост. Сеуште е во развој, затоа ве молиме пријавете ги сите проблеми кои ќе ги најдете.",
    "Dyslexia font" : "Фонт за дислексија",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic е бесплатен фонт дизајниран за ублажување на некои од честите грешки во читањето предизвикани од дислексија.",
    "Accessibility" : "Пристапност",
    "Accessibility options for nextcloud" : "Опции за пристапност на Nextcloud. ",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Овозможува повеќе опции за пристапност за да се олесни употребата на Nextcloud",
    "Web Content Accessibility Guidelines" : "Упатства за пристапност на веб содржини",
    "our issue tracker" : "нашиот следач на проблеми",
    "our design team" : "нашиот тим за дизајн",
    "Enable" : "овозможи",
    "Dark theme (beta)" : "Темна тема (бета)"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
